@@ -24,6 +24,7 @@ This is searched by gedit for a class extending gedit.Plugin
 
 import logging
 import string
+from traceback import print_exc
 
 from gi.repository import Gedit, GObject, Gio, Gtk, PeasGtk
 
@@ -54,7 +55,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
     # ui definition template for hooking tools in Gedit's ui.
     _tool_ui_template = string.Template("""<ui>
             <menubar name="MenuBar">
-                <menu name="ToolsMenu" action="Tools">
+                <menu name="ToolsMenu" action="ToolsDummyAction">
                     <placeholder name="ToolsOps_1">$items</placeholder>
                 </menu>
             </menubar>
@@ -74,6 +75,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         """
         Called when the window extension is activated
         """
+
         self._preferences = Preferences()
         self._tool_preferences = ToolPreferences()
         self._tool_preferences.connect("tools-changed", self._on_tools_changed)
@@ -89,16 +91,13 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         self._init_views()
         self._init_tab_decorators()
 
-        # FIXME: find another way to save a document
-        self._save_action = self._ui_manager.get_action("/MenuBar/FileMenu/FileSaveMenu")
-
         #
         # listen to tab signals
         #
         self._signal_handlers = [
                 self.window.connect("tab_added", self._on_tab_added),
                 self.window.connect("tab_removed", self._on_tab_removed),
-                self.window.connect("active_tab_changed", self._on_active_tab_changed)]
+                ]
 
     def do_deactivate(self):
         """
@@ -161,7 +160,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         """
         Merge the plugin's UI definition with the one of Gedit and hook the actions
         """
-        self._ui_manager = self.window.get_ui_manager()
+        self._ui_manager = Gtk.UIManager()
         self._action_group = Gtk.ActionGroup("LaTeXWindowActivatableActions")
         self._icon_factory = Gtk.IconFactory()
         self._icon_factory.add_default()
@@ -175,6 +174,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         for clazz in ACTIONS:
             action = clazz(icon_factory=self._icon_factory)
             action.hook(self._action_group, self._window_context)
+            action.simplehook(self.window, self._window_context)
 
             self._action_objects[clazz.__name__] = action
 
@@ -184,8 +184,10 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
                 else:
                     self._action_extensions[extension] = [clazz.__name__]
 
-        toolbar_mode = self._preferences.get("toolbar-mode")
-
+        #toolbar_mode = self._preferences.get("toolbar-mode")
+        # force normal mode
+        toolbar_mode = "normal"
+        
         # merge ui
         self._ui_manager.insert_action_group(self._action_group, -1)
         self._ui_id = self._ui_manager.add_ui_from_file(Resources().get_ui_file("ui-toolbar-%s.builder" % toolbar_mode))
@@ -195,9 +197,17 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             self._toolbar_name = "LaTeXToolbar"
             self._toolbar.set_style(Gtk.ToolbarStyle.BOTH_HORIZ)
             # FIXME: Adding a new toolbar to gedit is not really public API
-            self._main_box = self.window.get_children()[0]
-            self._main_box.pack_start(self._toolbar, False, True, 0)
-            self._main_box.reorder_child(self._toolbar, 2)
+            try:
+                # We assume the spot below exists
+                self._main_box = self.window.get_children()[0].get_children()[0].get_children()[0].get_children()[1]
+                self._main_box.pack_start(self._toolbar, False, True, 0)
+                self._main_box.reorder_child(self._toolbar, 1)
+            except (IndexError, AttributeError, TypeError) as e:
+                print_exc()
+                print()
+                print("Could not find place for the toolbar. Disabling toolbar.")
+                self_toolbar = None
+                self._toolbar_name = ""
         elif toolbar_mode == "combined":
             self._toolbar = None
             self._toolbar_name = "ToolBar"
@@ -205,7 +215,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             self._toolbar = None
             self._toolbar_name = ""
             LOG.info("Toolbar disabled")    
-
+            
     def _init_tab_decorators(self):
         """
         Look for already open tabs and create decorators for them
@@ -258,6 +268,11 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             action = ToolAction(tool)
             gtk_action = Gtk.Action(name, action.label, action.tooltip, action.stock_id)
             self._action_handlers[gtk_action] = gtk_action.connect("activate", lambda gtk_action, action: action.activate(self._window_context), action)
+            
+            # create simple actions to be used by menu (created in appactivatable.py)
+            simpleaction = Gio.SimpleAction(name=name)
+            simpleaction.connect("activate", lambda _a, _b, action: action.activate(self._window_context), action)
+            self.window.add_action(simpleaction)
 
             accelerator = None
             if tool.accelerator and len(tool.accelerator) > 0:
@@ -287,7 +302,8 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
 
         (used by ToolAction before tool run)
         """
-        self._save_action.activate()
+        tab = self._active_tab_decorator.tab
+        Gedit.commands_save_document(tab.get_toplevel(), tab.get_document())
 
     def show_toolbar(self):
         if self._toolbar:
@@ -332,8 +348,14 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
 
         if Gedit.utils_is_valid_location(gfile):
             LOG.debug("GeditWindow.create_tab_from_uri(%s)" % uri)
+            try:
+                view = self.window.get_active_view()
+                encoding = view.get_buffer().get_encoding()
+            except AttributeError:
+                # No document open
+                encoding = None
             self.window.create_tab_from_location(
-                            gfile, Gedit.encoding_get_current(),
+                            gfile, encoding,
                             1, 1, False, True)
         else:
             LOG.error("Gedit.utils.uri_is_valid(%s) = False" % uri)
@@ -360,7 +382,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         (the file type it contains)
 
         Called by
-         * _on_active_tab_changed()
+         * do_update_state()
          * GeditTabDecorator when the Editor instance changes
         """
 
@@ -380,44 +402,33 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
         # FIXME: we are dealing with sets so saving the index as selection state
         # is nonsense
         #
-
-        # disable all actions
-        for name in self._action_objects:
-            self._action_group.get_action(name).set_visible(False)
-
-        # disable all tool actions
-        for l in list(self._tool_action_extensions.values()):
-            for name in l:
-                self._tool_action_group.get_action(name).set_sensitive(False)
-
-        # enable the actions for all extensions
-        for name in self._action_extensions[None]:
-            self._action_group.get_action(name).set_visible(True)
-
-        # enable the actions registered for the extension
-        if extension:
-            try:
-                for name in self._action_extensions[extension]:
-                    self._action_group.get_action(name).set_visible(True)
-            except KeyError:
-                pass
-
-        # enable the tool actions that apply for all extensions
-        for name in self._tool_action_extensions[None]:
-            self._tool_action_group.get_action(name).set_sensitive(True)
-
-        # enable the tool actions that apply for this extension
-        if extension:
-            try:
-                for name in self._tool_action_extensions[extension]:
-                    self._tool_action_group.get_action(name).set_sensitive(True)
-            except KeyError:
-                pass
-
-        if extension:
-            self.show_toolbar()
-        else:
-            self.hide_toolbar()
+        
+        for category, catalog in (('actions', self._action_extensions),
+                                  ('tools', self._tool_action_extensions)):
+            # enable actions for all extensions
+            to_enable = set(catalog[None])
+            # enable the actions registered for the extension
+            if extension:
+                try:
+                    to_enable.update(catalog[extension])
+                except KeyError:
+                    pass
+            for name in set().union(*catalog.values()):
+                action = self.window.lookup_action(name)
+                action.set_enabled(name in to_enable)
+            
+            if category == 'tools':
+                # Show/hide the tool menu itself onlyif any action is shown:
+                menu_action = self.window.lookup_action('ToolsDummyAction')
+                # FIXME: This line spits "Gtk-WARNING"s which I really don't
+                # understand (when "to_enable" is not empty):
+                # "Duplicate child name in GtkStack: LaTeX Tools"
+                menu_action.set_enabled(bool(to_enable))
+        
+                if to_enable:
+                    self.show_toolbar()
+                else:
+                    self.hide_toolbar()
 
         #
         # adjust editor views
@@ -449,7 +460,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             if view in self._side_views:
                 view.show()
             else:
-                self.window.get_side_panel().add_item(view, "after_side_view_id" + str(i), view.get_label(), view.get_icon())
+                self.window.get_side_panel().add_titled(view, "after_side_view_id" + str(i), view.get_label())
                 self._side_views.append(view)
                 i += 1
 
@@ -458,7 +469,7 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             if view in self._bottom_views:
                 view.show()
             else:
-                self.window.get_bottom_panel().add_item(view, "bottom_view_id" + str(i), view.get_label(), view.get_icon())
+                self.window.get_bottom_panel().add_titled(view, "bottom_view_id" + str(i), view.get_label())
                 self._bottom_views.append(view)
                 i += 1
 
@@ -505,13 +516,16 @@ class LaTeXWindowActivatable(GObject.Object, Gedit.WindowActivatable, PeasGtk.Co
             # no more tabs
             self.disable()
 
-    def _on_active_tab_changed(self, window, tab):
+    def do_update_state(self):
         """
         The active tab has changed
 
-        @param window: the GeditWindow
-        @param tab: the activated GeditTab
         """
+        
+        tab = self.window.get_active_tab()
+        if not tab:
+            # Initialization time
+            return
         LOG.debug("active_tab_changed")
 
         if tab in list(self._tab_decorators.keys()):
